package com.lantone.qc.kernel.catalogue.deathcasediscuss;

import com.lantone.qc.dbanaly.util.KernelConstants;
import com.lantone.qc.dbanaly.util.SpecialStorageUtil;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @ClassName : DEAC03146
 * @Description :  死亡病例讨论未由科主任主持讨论
 * @Author :kwz
 * @Date: 2021-08-23 15:38
 */
@Component
public class DEAC03146 extends QCCatalogue {
    /**
     * 死亡病例讨论记录存在       【主任人】为科室主任姓名
     * @param inputInfo
     * @param outputInfo
     */
    @Autowired
    private SpecialStorageUtil specialStorageUtil;

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getDeathCaseDiscussDoc() != null) {
            Map<String, String> deathCaseDiscussStructureMap = inputInfo.getDeathCaseDiscussDoc().getStructureMap();
            if(deathCaseDiscussStructureMap!=null) {
                //其中有个字段为  职务-->科主任
                String recordDoctor = deathCaseDiscussStructureMap.get("讨论主持人");
                if (CatalogueUtil.isEmpty(recordDoctor)) {
                    if(!findDirectorDoctor(recordDoctor)) {
                        status.set("-1");
                    }
                }
            }
        }
    }
    //判断姓名是否为科室主任
    private boolean findDirectorDoctor(String recordDoctor) {
        Map<String, Map<String, Object>> hospitalDoctorMap = specialStorageUtil.getJsonStringValue(KernelConstants.HOSPITAL_DOCTOR_MAP);
        if (hospitalDoctorMap == null) {
            return false;
        }
        if (hospitalDoctorMap.containsKey(recordDoctor)) {
            Object professor = hospitalDoctorMap.get(recordDoctor).get("professor");
            if (professor != null) {
                if(professor.toString().contains("主任")) {
                    return true;
                }
            }
        }
        return false;
    }
}