package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.dbanaly.util.KernelConstants;
import com.lantone.qc.dbanaly.util.SpecialStorageUtil;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.DateUtil;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03147
 * @Description : 患者出院前48小时内无上级医师(主治及以上)同意出院的病程记录
 * @Author : 胡敬
 * @Date: 2020-03-19 13:51
 */
@Component
public class THR03147 extends QCCatalogue {
    @Autowired
    private SpecialStorageUtil specialStorageUtil;
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 出院时间前48小时，48小时内找上级医师同意出院的病程记录
         *
         * 以患者病案首页【出院时间】找前48小时内【查房记录】，查房记录标题或查房记录内容或医生签字包含【上级/主任/主治/主治及以上医师姓名】和查房记录内容包含【出院】同时存在
         */
        status.set("0");
        if(inputInfo.getFirstPageRecordDoc()==null || inputInfo.getFirstPageRecordDoc().getStructureMap()==null){
            return;
        }
        //获取病案首页出院时间
        String dischargeTime = inputInfo.getFirstPageRecordDoc().getStructureMap().get("出院时间");
        if (CatalogueUtil.isEmpty(dischargeTime)) {
            return;
        }
        Date dischargeDate = StringUtil.parseDateTime(dischargeTime);
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        if(ListUtil.isEmpty(threeLevelWardDocs)){
            return;
        }
        List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
        if(ListUtil.isEmpty(allDoctorWradDocs)){
            return;
        }
        if(!getAllPatientRounds(allDoctorWradDocs,dischargeDate)){
            status.set("-1");
            return;
        }

    }


    //获取患者出院前48小时内所有的查房记录并判断
    public  boolean getAllPatientRounds(List<ThreeLevelWardDoc> allDoctorWradDocs ,Date dischargeDate){
        boolean flag=true;
        List<String> superiorList = Content.superiorList;
        for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
            Map<String, String> structureMap = allDoctorWradDoc.getStructureMap();
            if(structureMap==null){
                continue;
            }
            String checkTheTime = structureMap.get("查房日期");
            if (CatalogueUtil.isEmpty(checkTheTime)) {
                continue;
            }
            Date checkTheDate = StringUtil.parseDateTime(checkTheTime);
            if(!CatalogueUtil.compareTime(
                    checkTheDate,
                    dischargeDate,
                    Long.valueOf(48 * 60))){
                flag=false;
                //出院前48小时的查房记录
                String illnessRecords = structureMap.get("病情记录");
                //包含出院
                if(StringUtil.isNotEmpty(illnessRecords)){
                if(illnessRecords.contains("出院")) {
                    // 查房记录标题或查房记录内容或医生签字包含【上级/主任/主治/主治及以上医师姓名】
                    String roundTitle = structureMap.get("查房标题");
                    //标题判断
                    if (StringUtil.isNotEmpty(roundTitle)) {
                        for (String superior : superiorList) {
                            if (roundTitle.contains(superior)) {
                                flag=true;
                                break;
                            }
                        }
                       if(judgeContainsDoctor(roundTitle)){
                            flag=true;
                            break;
                        }
                    }
                    //查房记录判断
                        for (String superior : superiorList) {
                            if (illnessRecords.contains(superior)) {
                                flag=true;
                                break;
                            }
                        }
                    if(judgeContainsDoctor(illnessRecords)){
                        flag=true;
                        break;
                    }
                    //审核人判断
                    String reviewer = structureMap.get("审核人");
                    if (StringUtil.isNotEmpty(reviewer)) {
                        for (String superior : superiorList) {
                            if (reviewer.contains(superior)) {
                                flag=true;
                                break;
                            }
                        }
                        if(judgeContainsDoctor(reviewer)){
                            flag=true;
                            break;
                        }
                    }
                }
                }
            }
        }
        return flag;
    }

    //判断是否含有主治及以上医师姓名
    private boolean judgeContainsDoctor(String string) {
        List<String> indicationsAboveList = Content.indicationsAboveList;
        Map<String, Map<String, Object>> hospitalDoctorMap = specialStorageUtil.getJsonStringValue(KernelConstants.HOSPITAL_DOCTOR_MAP);
        if (hospitalDoctorMap == null) {
            return false;
        }
        //主治及以上   主治，主任，副主任
        for (String keyStr : hospitalDoctorMap.keySet()) {
            if (string.contains(keyStr)) {
                Object professor = hospitalDoctorMap.get(keyStr).get("professor");
                if (professor != null) {
                    for (String indicationsAbove : indicationsAboveList) {
                        if (professor.toString().contains(indicationsAbove)) {
                            return true;
                        }
                    }
                }
            }
        }
        return false;
    }

}